function [xopt,lambda,how]=lpsolve(f,A,B,x0,solver);
% LPSOLVE: solve an LP problem with the desired solver (LP.M/CPLEX/E04MBF)
%
% [xopt,lambda,how]=LPSOLVE(f,A,B,x0,solver);
%
% Solve an LP problem by using the method specified in SOLVER:
%
% solver=2: uses LP_CPLEX.DLL
% solver=1: uses LP.M
% solver=0: uses E04MBF.M
%
%(C) 2000 by A. Bemporad, Zurich, 23/5/2000

B=B(:);
f=f(:);

switch solver
case 1,
   aux=evalc('[xopt,lambda,how]=lp(f,A,B,[],[],x0);');
case 0
   itmax=50;
   
   [aux1,aux2]=size(A);
   aux=evalc(['[xopt,istate,objlp,clambda,ifail]=e04mbf(' ...
         '-1e8*ones(aux1+aux2,1),[1e8*ones(aux2,1);B]' ...
         ',x0,f,A,0,itmax,-1);']);
   
   switch ifail
   case 0
      how = 'ok';
   case 2
      how = 'unbounded';
   case 1
      how = 'infeasible';
   case {3,4}
      % might also be considered as infeasible %
      warning('LP is cycling or too few iterations')
      how = 'infeasible';
   case {5}
      error('An input parameter is invalid.');
   otherwise
      error('other error code in "ifail" from e04mbf')
   end
   lambda=-clambda(aux2+1:aux1+aux2);
case 2
   ctype= char('L'*ones(size(A,1),1));
   ctype(size(A,1)+1:size(A,1))=char('E');
   [xopt,fmindum,status,lambda] = lp_cplex(1,f,A,B,ctype,-1e5*ones(size(A,2),1),1e5*ones(size(A,2),1),[],[],[],1);
   switch status
   case {1}   % feasible
      how = 'ok';
   case {0,2} % infeasible
      how = 'infeasible';
   case {3}   % unbounded
      how = 'unbounded';
   otherwise
      how = 'infeasible';
   end
   lambda=-lambda;
end   

