function [XX,TT,RR]=pwa_sim(P,x0,U,tol)
% [XX,TT,RR]=pwa_sim(P,x0,U,tol)
%
% Simulate the PWA system P from initial condition x0 and for
% the sequence of inputs U. RR stores the region number.
% The parameter tol (default: 1e-6) is used as a tolerance for assessing that
% Hx*x+Hu*u<=K.
%
% (C) 2001 by Alberto Bemporad, Zurich, 4/4/2001

nx=P.nx;
nu=P.nu;
nxr=P.nxr;
nur=P.nur;

if nargin<4,
   tol=1e-6;
end

Tstop=size(U,1); % Simulation runs for k=0, 1, ..., Tstop, t=Ts*k

XX=zeros(Tstop,nx);
RR=zeros(Tstop,1);
TT=(0:Tstop-1)';

x=x0(:); % Current state x(t)


for t=1:Tstop,
   u = U(t,:)';
   
   % Find region where (x,u) lies
   flag=7;
   i=0;
   while flag==7 & i<P.n,
      i=i+1;
      if all(P.Hx{i}*x+P.Hu{i}*u<=P.K{i}+tol),
         flag=1;
         A=[P.A{i};P.AL{i}];
         B=[P.B{i};P.BL{i}];
         f=[P.f{i};P.fL{i}];
      end
	end
      
   XX(t,:)=x';
   
   % disp(sprintf('t=%7.2f: x1=%7.2f, x2=%7.2f. MILP_FLAG=%d',t*Ts,x(1),x(2),flag))
   if (flag~=7) 
      x=A*x(1:nxr)+B*u(1:nur)+f;
      RR(t)=i;
   else 
      error(sprintf('PWA infeasibility at simulation step k=%d !',t-1));
   end
   
   %X=[X,x];
end
